@@ -91,6 +91,7 @@ main(argc, argv)
 	struct winsize win;
 	int aflg, ch;
 	char ibuf[BUFSIZ];
+	struct stat statbuf;
 
 	aflg = 0;
 	while ((ch = getopt(argc, argv, "a")) != EOF)
@@ -118,6 +119,13 @@ main(argc, argv)
 	(void)ioctl(STDIN_FILENO, TIOCGWINSZ, &win);
 	if (openpty(&master, &slave, NULL, &tt, &win) == -1)
 		err("openpty: %s", strerror(errno));
+	if (fstat(slave, &statbuf) == -1)
+		err("pty slave: %s", strerror(errno));
+	if (statbuf.st_mode & S_IRWXO)
+		fprintf(stderr, "script: WARNING: script session is not"
+		                " secure against eavesdropping/hijacking!\n"
+		                "script: read /usr/doc/bsdutils/README.script"
+		                " for details.\n");
 
 	(void)printf("Script started, output file is %s\n", fname);
 	rtt = tt;
